@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -27,7 +27,9 @@ class BtoeClient(AbstractClient):
 
 
     def CreateAudioDeposit(self, request):
-        """用户通过本接口向BTOE写入待存证的音频原文件或下载URL，BTOE对音频原文件存储后，将其Hash值存证上链，并生成含有电子签章的区块链存证电子凭证。音频类型支持格式：mp3、wav、wma、midi、flac；原文件上传大小不超过5 MB，下载URL文件大小不超过25 MB。
+        """功能迭代，已上线更高版本的接口2021-05-14
+
+        用户通过本接口向BTOE写入待存证的音频原文件或下载URL，BTOE对音频原文件存储后，将其Hash值存证上链，并生成含有电子签章的区块链存证电子凭证。音频类型支持格式：mp3、wav、wma、midi、flac；原文件上传大小不超过5 MB，下载URL文件大小不超过25 MB。
 
         :param request: Request instance for CreateAudioDeposit.
         :type request: :class:`tencentcloud.btoe.v20210303.models.CreateAudioDepositRequest`
@@ -55,7 +57,9 @@ class BtoeClient(AbstractClient):
 
 
     def CreateDataDeposit(self, request):
-        """用户通过本接口向BTOE写入待存证的业务数据明文，业务数据明文存证写入后不可修改，BTOE对业务数据明文存证生成含有电子签章的区块链存证电子凭证。
+        """功能迭代，已上线更高版本的接口2021-05-14
+
+        用户通过本接口向BTOE写入待存证的业务数据明文，业务数据明文存证写入后不可修改，BTOE对业务数据明文存证生成含有电子签章的区块链存证电子凭证。
 
         :param request: Request instance for CreateDataDeposit.
         :type request: :class:`tencentcloud.btoe.v20210303.models.CreateDataDepositRequest`
@@ -83,7 +87,9 @@ class BtoeClient(AbstractClient):
 
 
     def CreateDocDeposit(self, request):
-        """用户通过本接口向BTOE写入待存证的文档原文件或下载URL，BTOE对文档原文件存储后，将其Hash值存证上链，并生成含有电子签章的区块链存证电子凭证。文档类型支持格式：doc、docx、xls、xlsx、ppt、pptx、 pdf、html、txt、md、csv；原文件上传大小不超过5 MB，下载URL文件大小不超过10 MB。
+        """功能迭代，已上线更高版本的接口2021-05-14
+
+        用户通过本接口向BTOE写入待存证的文档原文件或下载URL，BTOE对文档原文件存储后，将其Hash值存证上链，并生成含有电子签章的区块链存证电子凭证。文档类型支持格式：doc、docx、xls、xlsx、ppt、pptx、 pdf、html、txt、md、csv；原文件上传大小不超过5 MB，下载URL文件大小不超过10 MB。
 
         :param request: Request instance for CreateDocDeposit.
         :type request: :class:`tencentcloud.btoe.v20210303.models.CreateDocDepositRequest`
@@ -111,7 +117,9 @@ class BtoeClient(AbstractClient):
 
 
     def CreateHashDeposit(self, request):
-        """用户通过本接口向BTOE写入待存证的原文数据Hash值，BTOE对业务数据Hash值存证上链，并生成含有电子签章的区块链存证电子凭证。
+        """功能迭代，已上线更高版本的接口2021-05-14
+
+        用户通过本接口向BTOE写入待存证的原文数据Hash值，BTOE对业务数据Hash值存证上链，并生成含有电子签章的区块链存证电子凭证。
 
         :param request: Request instance for CreateHashDeposit.
         :type request: :class:`tencentcloud.btoe.v20210303.models.CreateHashDepositRequest`
@@ -139,7 +147,9 @@ class BtoeClient(AbstractClient):
 
 
     def CreateHashDepositNoCert(self, request):
-        """用户通过本接口向BTOE写入待存证的原文数据Hash值，BTOE对业务数据Hash值存证上链，本接口不生成区块链存证电子凭证。
+        """功能迭代，已上线更高版本的接口2021-05-14
+
+        用户通过本接口向BTOE写入待存证的原文数据Hash值，BTOE对业务数据Hash值存证上链，本接口不生成区块链存证电子凭证。
 
         :param request: Request instance for CreateHashDepositNoCert.
         :type request: :class:`tencentcloud.btoe.v20210303.models.CreateHashDepositNoCertRequest`
@@ -167,7 +177,9 @@ class BtoeClient(AbstractClient):
 
 
     def CreateHashDepositNoSeal(self, request):
-        """用户通过本接口向BTOE写入待存证的原文数据Hash值，BTOE对业务数据Hash值存证上链，并生成无电子签章的区块链存证电子凭证。
+        """功能迭代，已上线更高版本的接口2021-05-14
+
+        用户通过本接口向BTOE写入待存证的原文数据Hash值，BTOE对业务数据Hash值存证上链，并生成无电子签章的区块链存证电子凭证。
 
         :param request: Request instance for CreateHashDepositNoSeal.
         :type request: :class:`tencentcloud.btoe.v20210303.models.CreateHashDepositNoSealRequest`
@@ -195,7 +207,9 @@ class BtoeClient(AbstractClient):
 
 
     def CreateImageDeposit(self, request):
-        """用户通过本接口向BTOE写入待存证的图片原文件或下载URL，BTOE对图片原文件存储后，将其Hash值存证上链，并生成含有电子签章的区块链存证电子凭证。图片类型支持格式：png、jpg、jpeg、bmp、gif、svg；原文件上传大小不超过5 MB，下载URL文件大小不超过10 MB。
+        """功能迭代，已上线更高版本的接口2021-05-14
+
+        用户通过本接口向BTOE写入待存证的图片原文件或下载URL，BTOE对图片原文件存储后，将其Hash值存证上链，并生成含有电子签章的区块链存证电子凭证。图片类型支持格式：png、jpg、jpeg、bmp、gif、svg；原文件上传大小不超过5 MB，下载URL文件大小不超过10 MB。
 
         :param request: Request instance for CreateImageDeposit.
         :type request: :class:`tencentcloud.btoe.v20210303.models.CreateImageDepositRequest`
@@ -223,7 +237,9 @@ class BtoeClient(AbstractClient):
 
 
     def CreateVideoDeposit(self, request):
-        """用户通过本接口向BTOE写入待存证的视频的原文件或下载URL，BTOE对视频原文件存储后，将其Hash值存证上链，并生成含有电子签章的区块链存证电子凭证。视频文件支持格式：mp4、avi、mkv、mov、flv,wmv,rmvb,3gp；文件大小限制：直接上传原文件不大于5MB，下载URL文件大小不大于200 MB。
+        """功能迭代，已上线更高版本的接口2021-05-14
+
+        用户通过本接口向BTOE写入待存证的视频的原文件或下载URL，BTOE对视频原文件存储后，将其Hash值存证上链，并生成含有电子签章的区块链存证电子凭证。视频文件支持格式：mp4、avi、mkv、mov、flv,wmv,rmvb,3gp；文件大小限制：直接上传原文件不大于5MB，下载URL文件大小不大于200 MB。
 
         :param request: Request instance for CreateVideoDeposit.
         :type request: :class:`tencentcloud.btoe.v20210303.models.CreateVideoDepositRequest`
@@ -251,7 +267,9 @@ class BtoeClient(AbstractClient):
 
 
     def CreateWebpageDeposit(self, request):
-        """用户通过本接口向BTOE提交待存证网页的URL，BTOE对URL进行网页快照，并将快照图片存储，将网页快照Hash值存证上链，并生成含有电子签章的区块链存证电子凭证。URL格式必须以http、https开头。
+        """功能迭代，已上线更高版本的接口2021-05-14
+
+        用户通过本接口向BTOE提交待存证网页的URL，BTOE对URL进行网页快照，并将快照图片存储，将网页快照Hash值存证上链，并生成含有电子签章的区块链存证电子凭证。URL格式必须以http、https开头。
 
         :param request: Request instance for CreateWebpageDeposit.
         :type request: :class:`tencentcloud.btoe.v20210303.models.CreateWebpageDepositRequest`
@@ -279,7 +297,9 @@ class BtoeClient(AbstractClient):
 
 
     def GetDepositCert(self, request):
-        """用户通过存证编码向BTOE查询存证电子凭证信息。
+        """功能迭代，已上线更高版本的接口2021-05-14
+
+        用户通过存证编码向BTOE查询存证电子凭证信息。
 
         :param request: Request instance for GetDepositCert.
         :type request: :class:`tencentcloud.btoe.v20210303.models.GetDepositCertRequest`
@@ -307,7 +327,9 @@ class BtoeClient(AbstractClient):
 
 
     def GetDepositFile(self, request):
-        """用户通过存证编码向BTOE获取存证文件的下载URL。
+        """功能迭代，已上线更高版本的接口2021-05-14
+
+        用户通过存证编码向BTOE获取存证文件的下载URL。
         -注：Hash类存证、业务数据明文存证不产生存证文件。
 
         :param request: Request instance for GetDepositFile.
@@ -336,7 +358,9 @@ class BtoeClient(AbstractClient):
 
 
     def GetDepositInfo(self, request):
-        """用户通过存证编码向BTOE查询存证基本信息。
+        """功能迭代，已上线更高版本的接口2021-05-14
+
+        用户通过存证编码向BTOE查询存证基本信息。
 
         :param request: Request instance for GetDepositInfo.
         :type request: :class:`tencentcloud.btoe.v20210303.models.GetDepositInfoRequest`
