@@ -71,6 +71,9 @@ INTERNALERROR_SCDNUSERNOPACKAGE = 'InternalError.ScdnUserNoPackage'
 # 安全加速服务已停服，请重新购买套餐后开启。
 INTERNALERROR_SCDNUSERSUSPEND = 'InternalError.ScdnUserSuspend'
 
+# 内部数据错误，请重试或联系客服人员解决。
+INTERNALERROR_SYSTEMDBERROR = 'InternalError.SystemDBError'
+
 # 内部服务错误，请联系腾讯云工程师进一步排查。
 INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'
 
@@ -134,7 +137,7 @@ INVALIDPARAMETER_CDNCONFIGTAGREQUIRED = 'InvalidParameter.CdnConfigTagRequired'
 # 域名拥有特殊配置，需人工处理。
 INVALIDPARAMETER_CDNHOSTHASSPECIALCONFIG = 'InvalidParameter.CdnHostHasSpecialConfig'
 
-# 内部域名不允许接入。
+# 该域名为内部域名，不可接入。
 INVALIDPARAMETER_CDNHOSTINTERNALHOST = 'InvalidParameter.CdnHostInternalHost'
 
 # 错误的中间源配置。
@@ -314,6 +317,9 @@ LIMITEXCEEDED_SCDNLOGTASKEXCEEDDAYLIMIT = 'LimitExceeded.ScdnLogTaskExceedDayLim
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 操作被拒绝。
+OPERATIONDENIED = 'OperationDenied'
+
 # 请求的次数超过了频率限制。
 REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
 
