@@ -104,6 +104,9 @@ INVALIDPARAMETERVALUE_DEVICENAMEINVALID = 'InvalidParameterValue.DeviceNameInval
 # 任务不存在。
 INVALIDPARAMETERVALUE_ERRORTASKNOTEXIST = 'InvalidParameterValue.ErrorTaskNotExist'
 
+# 存失败，行为操作和转发错误行为数据目标不可为同一设备。
+INVALIDPARAMETERVALUE_FAILACTIONHASSAMEDEVICE = 'InvalidParameterValue.FailActionHasSameDevice'
+
 # 固件已经存在。
 INVALIDPARAMETERVALUE_FIRMWAREALREADYEXIST = 'InvalidParameterValue.FirmwareAlreadyExist'
 
@@ -173,6 +176,9 @@ INVALIDPARAMETERVALUE_MSGTITLEINVALID = 'InvalidParameterValue.MsgTitleInvalid'
 # 消息类型非法。
 INVALIDPARAMETERVALUE_MSGTYPEINVALID = 'InvalidParameterValue.MsgTypeInvalid'
 
+# 操作不支持。
+INVALIDPARAMETERVALUE_OPERATIONDENIED = 'InvalidParameterValue.OperationDenied'
+
 # 创建的产品名已存在。
 INVALIDPARAMETERVALUE_PRODUCTALREADYEXIST = 'InvalidParameterValue.ProductAlreadyExist'
 
@@ -188,6 +194,9 @@ INVALIDPARAMETERVALUE_PROJECTPARMSERROR = 'InvalidParameterValue.ProjectParmsErr
 # 规则数量超过限制。
 INVALIDPARAMETERVALUE_RULENUMBERBEYONDLIMIT = 'InvalidParameterValue.RuleNumberBeyondLimit'
 
+# 开始时间晚于结束时间。
+INVALIDPARAMETERVALUE_STARTTIMELATERENDTIME = 'InvalidParameterValue.StartTimeLaterEndTime'
+
 # Topic已存在。
 INVALIDPARAMETERVALUE_TOPICPOLICYALREADYEXIST = 'InvalidParameterValue.TopicPolicyAlreadyExist'
 
@@ -248,6 +257,12 @@ RESOURCENOTFOUND_DEVICENOTEXIST = 'ResourceNotFound.DeviceNotExist'
 # 设备没有影子信息。
 RESOURCENOTFOUND_DEVICESHADOWNOTEXIST = 'ResourceNotFound.DeviceShadowNotExist'
 
+# 围栏未绑定该设备。
+RESOURCENOTFOUND_FENCEBINDNOTEXIST = 'ResourceNotFound.FenceBindNotExist'
+
+# 围栏未创建或是已删除。
+RESOURCENOTFOUND_FENCENOTEXIST = 'ResourceNotFound.FenceNotExist'
+
 # 固件不存在。
 RESOURCENOTFOUND_FIRMWARENOTEXIST = 'ResourceNotFound.FirmwareNotExist'
 
@@ -278,12 +293,18 @@ RESOURCENOTFOUND_PRODUCTRESOURCENOTEXIST = 'ResourceNotFound.ProductResourceNotE
 # 项目不存在。
 RESOURCENOTFOUND_PROJECTNOTEXIST = 'ResourceNotFound.ProjectNotExist'
 
+# 位置空间未创建或是已删除。
+RESOURCENOTFOUND_SPACENOTEXIST = 'ResourceNotFound.SpaceNotExist'
+
 # LoRa频点尚未创建或已被删除。
 RESOURCENOTFOUND_STUDIOLORAFREQNOTEXIST = 'ResourceNotFound.StudioLoRaFreqNotExist'
 
 # 产品不存在。
 RESOURCENOTFOUND_STUDIOPRODUCTNOTEXIST = 'ResourceNotFound.StudioProductNotExist'
 
+# Topic不存在。
+RESOURCENOTFOUND_TOPICPOLICYNOTEXIST = 'ResourceNotFound.TopicPolicyNotExist'
+
 # 规则不存在。
 RESOURCENOTFOUND_TOPICRULENOTEXIST = 'ResourceNotFound.TopicRuleNotExist'
 
@@ -308,6 +329,9 @@ UNAUTHORIZEDOPERATION_NOPERMISSIONTOINSTANCE = 'UnauthorizedOperation.NoPermissi
 # 项目ACL错误。
 UNAUTHORIZEDOPERATION_NOPERMISSIONTOPROJECT = 'UnauthorizedOperation.NoPermissionToProject'
 
+# 围栏ACL错误。
+UNAUTHORIZEDOPERATION_NOPERMISSIONTOSTUDIOFENCE = 'UnauthorizedOperation.NoPermissionToStudioFence'
+
 # 实例ACL错误。
 UNAUTHORIZEDOPERATION_NOPERMISSIONTOSTUDIOINSTANCE = 'UnauthorizedOperation.NoPermissionToStudioInstance'
 
@@ -326,6 +350,9 @@ UNAUTHORIZEDOPERATION_USERLICENSEEXCEEDLIMIT = 'UnauthorizedOperation.UserLicens
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
+# 围栏下还存在绑定的设备。
+UNSUPPORTEDOPERATION_BINDSEXISTUNDERFENCE = 'UnsupportedOperation.BindsExistUnderFence'
+
 # 创建的设备已经存在。
 UNSUPPORTEDOPERATION_DEVICEDUPKEYEXIST = 'UnsupportedOperation.DeviceDupKeyExist'
 
@@ -338,6 +365,12 @@ UNSUPPORTEDOPERATION_DEVICEOTATASKINPROGRESS = 'UnsupportedOperation.DeviceOtaTa
 # 产品下还存在未删除的设备。
 UNSUPPORTEDOPERATION_DEVICESEXISTUNDERPRODUCT = 'UnsupportedOperation.DevicesExistUnderProduct'
 
+# 存在重复围栏。
+UNSUPPORTEDOPERATION_FENCEDUPKEYEXIST = 'UnsupportedOperation.FenceDupKeyExist'
+
+# 位置空间下还存在未删除的围栏。
+UNSUPPORTEDOPERATION_FENCEEXISTUNDERSPACE = 'UnsupportedOperation.FenceExistUnderSpace'
+
 # 网关产品还绑定子产品，无法删除。
 UNSUPPORTEDOPERATION_GATEWAYPRODUCTHASBINDEDPRODUCT = 'UnsupportedOperation.GatewayProductHasBindedProduct'
 
@@ -371,6 +404,9 @@ UNSUPPORTEDOPERATION_PRODUCTHASBINDEDGATEWAYPRODUCT = 'UnsupportedOperation.Prod
 # 存在重复项目。
 UNSUPPORTEDOPERATION_PROJECTDUPKEYEXIST = 'UnsupportedOperation.ProjectDupKeyExist'
 
+# 存在重复位置空间。
+UNSUPPORTEDOPERATION_SPACEDUPKEYEXIST = 'UnsupportedOperation.SpaceDupKeyExist'
+
 # LoRa频点还被节点或网关使用。
 UNSUPPORTEDOPERATION_STUDIOLORAFREQINUSED = 'UnsupportedOperation.StudioLoRaFreqInUsed'
 
